from data.watchlist import ALL
from report.symbolhistory.symbolhistory import SymbolHistory
from robinhood.lib.account.account import account


account.update_in_parallel()
stock_order_sides = {'buy', 'sell'}
order_states = {'confirmed', 'filled', 'partially_filled', 'cancelled', 'rejected', 'failed'}
option_directions = {'credit', 'debit'}
option_event_states = {'confirmed', 'pending', 'voided'}
option_event_types = {'expiration', 'assignment', 'exercise'}
option_position_types = {'long', 'short'}
symbol_history = SymbolHistory(
    stock_orders=account.stock_orders,
    option_orders=account.option_orders,
    option_events=account.option_events,
)


def test_account_type() -> None:
    assert account.account_type == 'margin'


def test_account_margin_used() -> None:
    assert account.margin_used >= 0


def test_account_buying_power() -> None:
    assert account.buying_power >= 0


def test_account_active_symbols() -> None:
    assert len(account.active_symbols) >= 0


def test_stock_orders() -> None:
    assert len(account.stock_orders) > 0
    for stock_order in account.stock_orders:
        assert stock_order.side in stock_order_sides
        assert stock_order.state in order_states


def test_stock_positions() -> None:
    assert len(account.stock_positions) > 0
    for stock_position in account.stock_positions:
        assert ALL[stock_position.symbol] == stock_position.instrument_id
        assert stock_position.quantity >= 0


def test_option_orders() -> None:
    assert len(account.option_orders) > 0
    for option_order in account.option_orders:
        assert option_order.state in order_states
        assert option_order.direction in option_directions


def test_option_positions() -> None:
    assert len(account.option_positions) > 0
    for position in account.option_positions:
        assert position.position_type in option_position_types


def test_option_events() -> None:
    assert len(account.option_events) > 0
    for option_event in account.option_events:
        assert option_event.state in option_event_states
        assert option_event.event_type in option_event_types
        assert option_event.direction in option_directions


def test_symbol_history_adbe() -> None:
    data = symbol_history._gen_ascii_tbl_data(symbol='ADBE')
    example = [
        ['Date', 'Event', 'Symbol', 'Quantity', 'Price', '# of Shares', 'Avg Price', 'Cumulative Profit'],
        ['08/01/2018 14:25', 'LIMIT BUY', 'ADBE', '100', '$246.90', '100', '$246.90', '$0.00'],
        ['08/01/2018 14:35', 'SHORT CALL', 'ADBE20180803C252.5', '1', '$-0.40', '100', '$246.90', '$0.00'],
        ['08/03/2018 14:51', 'BUY TO CLOSE', 'ADBE20180803C252.5', '1', '$0.40', '100', '$246.90', '$0.00'],
        ['08/20/2018 14:30', 'SHORT CALL', 'ADBE20180824C255.0', '1', '$-0.75', '100', '$246.90', '$0.00'],
        ['08/20/2018 15:09', 'SHORT PUT', 'ADBE20180824P240.0', '1', '$-0.53', '100', '$246.90', '$0.00'],
        ['08/23/2018 14:42', 'BUY TO CLOSE', 'ADBE20180824P240.0', '1', '$0.04', '100', '$246.90', '$49.00'],
        ['08/24/2018 20:12', 'CALL ASSIGNMENT', 'ADBE20180824C255.0', '1', '$255.00', '0', '$0.00', '$934.00'],
        ['09/10/2018 13:57', 'SHORT PUT', 'ADBE20180914P252.5', '1', '$-2.70', '0', '$0.00', '$934.00'],
        ['09/14/2018 20:25', 'OPTION EXPIRATION', 'ADBE20180914P252.5', '1', '$0.00', '0', '$0.00', '$1,204.00'],
        ['10/10/2018 19:35', 'LIMIT BUY', 'ADBE', '100', '$240.00', '100', '$240.00', '$1,204.00'],
        ['12/14/2018 15:35', 'LIMIT BUY', 'ADBE', '50', '$234.00', '150', '$238.00', '$1,204.00'],
        ['06/17/2019 19:35', 'SHORT CALL', 'ADBE20190621C292.5', '1', '$-1.00', '150', '$238.00', '$1,204.00'],
        ['06/18/2019 13:46', 'SHORT PUT', 'ADBE20190628P260.0', '1', '$-1.66', '150', '$238.00', '$1,204.00'],
        ['06/21/2019 20:26', 'CALL ASSIGNMENT', 'ADBE20190621C292.5', '1', '$292.50', '50', '$238.00', '$6,754.00'],
        ['06/24/2019 13:46', 'SHORT PUT', 'ADBE20190628P292.5', '1', '$-1.15', '50', '$238.00', '$6,754.00'],
        ['06/25/2019 16:40', 'BUY TO CLOSE', 'ADBE20190628P260.0', '1', '$0.05', '50', '$238.00', '$6,915.00'],
        ['06/25/2019 16:41', 'SHORT PUT', 'ADBE20190628P285.0', '1', '$-0.98', '50', '$238.00', '$6,915.00'],
        ['06/28/2019 13:56', 'BUY TO CLOSE', 'ADBE20190628P285.0', '1', '$0.05', '50', '$238.00', '$7,008.00'],
        ['06/28/2019 19:55', 'BUY TO CLOSE', 'ADBE20190628P292.5', '1', '$0.04', '50', '$238.00', '$7,119.00'],
        ['06/28/2019 19:55', 'SHORT PUT', 'ADBE20190705P290.0', '1', '$-2.00', '50', '$238.00', '$7,119.00'],
        ['07/05/2019 20:24', 'OPTION EXPIRATION', 'ADBE20190705P290.0', '1', '$0.00', '50', '$238.00', '$7,319.00'],
        ['07/08/2019 14:43', 'SHORT PUT', 'ADBE20190712P292.5', '1', '$-0.60', '50', '$238.00', '$7,319.00'],
        ['07/12/2019 20:22', 'OPTION EXPIRATION', 'ADBE20190712P292.5', '1', '$0.00', '50', '$238.00', '$7,379.00'],
        ['08/05/2019 18:55', 'SHORT PUT', 'ADBE20190809P270.0', '1', '$-2.78', '50', '$238.00', '$7,379.00'],
        ['08/09/2019 20:24', 'OPTION EXPIRATION', 'ADBE20190809P270.0', '1', '$0.00', '50', '$238.00', '$7,657.00'],
        ['08/13/2019 16:18', 'SHORT PUT', 'ADBE20190816P292.5', '1', '$-2.64', '50', '$238.00', '$7,657.00'],
        [
            '08/14/2019 14:38',
            'ROLLING PUT', 'ADBE20190816P292.5/20190823P290.0', '1', '$-0.73', '50', '$238.00', '$7,657.00',
        ],
        ['08/14/2019 16:02', 'SHORT PUT', 'ADBE20190816P280.0', '1', '$-2.84', '50', '$238.00', '$7,657.00'],
        ['08/16/2019 20:38', 'OPTION EXPIRATION', 'ADBE20190816P280.0', '1', '$0.00', '50', '$238.00', '$7,941.00'],
        ['08/21/2019 17:41', 'SHORT PUT', 'ADBE20190823P287.5', '1', '$-1.54', '50', '$238.00', '$7,941.00'],
        ['08/23/2019 20:21', 'PUT ASSIGNMENT', 'ADBE20190823P287.5', '1', '$287.50', '150', '$269.97', '$7,941.00'],
        ['08/23/2019 20:21', 'PUT ASSIGNMENT', 'ADBE20190823P290.0', '1', '$290.00', '250', '$276.64', '$7,941.00'],
        ['08/26/2019 15:49', 'SHORT CALL', 'ADBE20190830C290.0', '2', '$-2.16', '250', '$276.64', '$7,941.00'],
        ['08/30/2019 20:22', 'OPTION EXPIRATION', 'ADBE20190830C290.0', '2', '$0.00', '250', '$276.64', '$8,373.00'],
        ['09/03/2019 16:10', 'SHORT CALL', 'ADBE20190906C287.5', '2', '$-1.95', '250', '$276.64', '$8,373.00'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_symbol_history_twtr() -> None:
    data = symbol_history._gen_ascii_tbl_data(symbol='TWTR')
    example = [
        ['Date', 'Event', 'Symbol', 'Quantity', 'Price', '# of Shares', 'Avg Price', 'Cumulative Profit'],
        ['06/15/2018 17:14', 'LIMIT BUY', 'TWTR', '100', '$46.70', '100', '$46.70', '$0.00'],
        ['07/09/2018 14:03', 'LIMIT BUY', 'TWTR', '100', '$43.80', '200', '$45.25', '$0.00'],
        ['07/09/2018 14:28', 'SHORT CALL', 'TWTR20180713C46.0', '2', '$-0.40', '200', '$45.25', '$0.00'],
        ['07/13/2018 20:13', 'OPTION EXPIRATION', 'TWTR20180713C46.0', '2', '$0.00', '200', '$45.25', '$80.00'],
        ['07/17/2018 13:35', 'SHORT CALL', 'TWTR20180727C48.0', '2', '$-1.14', '200', '$45.25', '$80.00'],
        ['07/20/2018 14:47', 'SHORT PUT', 'TWTR20180727P40.0', '1', '$-0.94', '200', '$45.25', '$80.00'],
        ['07/27/2018 20:12', 'PUT ASSIGNMENT', 'TWTR20180727P40.0', '1', '$40.00', '300', '$43.19', '$80.00'],
        ['07/27/2018 20:12', 'OPTION EXPIRATION', 'TWTR20180727C48.0', '2', '$0.00', '300', '$43.19', '$308.00'],
        [
            '08/08/2018 16:29',
            'LONG CALL SPREAD', 'TWTR20181019C31.0/20181019C34.0', '1', '$1.30', '300', '$43.19', '$308.00',
        ],
        [
            '08/08/2018 19:00',
            'CUSTOM', '-TWTR20181019C32.0/-TWTR20181019C44.0/-TWTR20181019P26.0/TWTR20181019C31.0',
            '1', '$0.05', '300', '$43.19', '$308.00',
        ],
        [
            '08/09/2018 14:19',
            'CUSTOM CLOSE', '-TWTR20181019C31.0-/TWTR20181019C32.0-/TWTR20181019C44.0-/TWTR20181019P26.0-',
            '1', '$0.03', '300', '$43.19', '$310.00',
        ],
        ['08/17/2018 14:55', 'LONG CALL', 'TWTR20181019C32.0', '1', '$2.40', '300', '$43.19', '$310.00'],
        ['08/22/2018 14:09', 'SHORT CALL', 'TWTR20180831C35.0', '1', '$-0.36', '300', '$43.19', '$310.00'],
        ['08/24/2018 15:41', 'BUY TO CLOSE', 'TWTR20180831C35.0', '1', '$0.36', '300', '$43.19', '$310.00'],
        ['08/27/2018 18:57', 'LONG CALL CLOSE', 'TWTR20181019C32.0', '1', '$-4.70', '300', '$43.19', '$540.00'],
        ['08/28/2018 14:23', 'SHORT PUT', 'TWTR20180831P34.0', '1', '$-0.15', '300', '$43.19', '$540.00'],
        ['08/31/2018 20:13', 'OPTION EXPIRATION', 'TWTR20180831P34.0', '1', '$0.00', '300', '$43.19', '$555.00'],
        ['09/04/2018 14:53', 'SHORT PUT', 'TWTR20180907P34.0', '1', '$-0.27', '300', '$43.19', '$555.00'],
        [
            '09/06/2018 13:43',
            'LONG CALL SPREAD CLOSE', 'TWTR20181019C31.0/20181019C34.0', '1', '$-1.36', '300', '$43.19', '$559.00',
        ],
        ['09/07/2018 20:57', 'PUT ASSIGNMENT', 'TWTR20180907P34.0', '1', '$34.00', '400', '$40.82', '$559.00'],
        ['10/24/2018 15:06', 'SHORT PUT', 'TWTR20181026P26.0', '2', '$-0.75', '400', '$40.82', '$559.00'],
        ['10/26/2018 20:26', 'OPTION EXPIRATION', 'TWTR20181026P26.0', '2', '$0.00', '400', '$40.82', '$709.00'],
        ['11/14/2018 19:05', 'LIMIT BUY', 'TWTR', '100', '$33.00', '500', '$39.26', '$709.00'],
        ['11/19/2018 16:04', 'LIMIT BUY', 'TWTR', '100', '$33.00', '600', '$38.22', '$709.00'],
        ['12/11/2018 16:24', 'LIMIT SELL', 'TWTR', '200', '$35.50', '400', '$38.22', '$166.00'],
        ['02/06/2019 20:37', 'SHORT CALL', 'TWTR20190208C40.0', '4', '$-0.33', '400', '$38.22', '$166.00'],
        ['02/08/2019 21:24', 'OPTION EXPIRATION', 'TWTR20190208C40.0', '4', '$0.00', '400', '$38.22', '$298.00'],
        ['04/22/2019 19:55', 'SHORT CALL', 'TWTR20190426C38.0', '1', '$-0.43', '400', '$38.22', '$298.00'],
        ['04/22/2019 19:59', 'SHORT PUT', 'TWTR20190426P31.0', '1', '$-0.47', '400', '$38.22', '$298.00'],
        ['04/23/2019 15:38', 'SHORT CALL', 'TWTR20190426C42.0', '1', '$-0.40', '400', '$38.22', '$298.00'],
        ['04/26/2019 20:24', 'OPTION EXPIRATION', 'TWTR20190426C42.0', '1', '$0.00', '400', '$38.22', '$338.00'],
        ['04/26/2019 20:24', 'OPTION EXPIRATION', 'TWTR20190426P31.0', '1', '$0.00', '400', '$38.22', '$385.00'],
        ['04/26/2019 20:24', 'CALL ASSIGNMENT', 'TWTR20190426C38.0', '1', '$38.00', '300', '$38.22', '$406.50'],
        ['04/29/2019 14:11', 'SHORT CALL', 'TWTR20190503C40.5', '1', '$-0.22', '300', '$38.22', '$406.50'],
        ['05/03/2019 20:23', 'CALL ASSIGNMENT', 'TWTR20190503C40.5', '1', '$40.50', '200', '$38.22', '$657.00'],
        ['05/22/2019 16:21', 'SHORT CALL', 'TWTR20190524C40.0', '2', '$-0.26', '200', '$38.22', '$657.00'],
        ['05/24/2019 20:23', 'OPTION EXPIRATION', 'TWTR20190524C40.0', '2', '$0.00', '200', '$38.22', '$709.00'],
        ['05/30/2019 15:19', 'SHORT CALL', 'TWTR20190607C38.5', '2', '$-0.38', '200', '$38.22', '$709.00'],
        ['06/07/2019 20:23', 'OPTION EXPIRATION', 'TWTR20190607C38.5', '2', '$0.00', '200', '$38.22', '$785.00'],
        ['06/10/2019 19:36', 'SHORT CALL', 'TWTR20190614C38.5', '2', '$-0.31', '200', '$38.22', '$785.00'],
        ['06/14/2019 20:22', 'OPTION EXPIRATION', 'TWTR20190614C38.5', '2', '$0.00', '200', '$38.22', '$847.00'],
        ['07/22/2019 14:14', 'SHORT CALL', 'TWTR20190726C39.5', '2', '$-0.86', '200', '$38.22', '$847.00'],
        ['07/22/2019 14:16', 'SHORT PUT', 'TWTR20190726P33.5', '4', '$-0.50', '200', '$38.22', '$847.00'],
        ['07/26/2019 20:22', 'OPTION EXPIRATION', 'TWTR20190726P33.5', '4', '$0.00', '200', '$38.22', '$1,047.00'],
        ['07/26/2019 20:22', 'CALL ASSIGNMENT', 'TWTR20190726C39.5', '2', '$39.50', '0', '$0.00', '$1,476.00'],
        [
            '07/31/2019 15:39',
            'SHORT CALL SPREAD', 'TWTR20190809C45.0/20190809C48.0', '4', '$-0.25', '0', '$0.00', '$1,476.00',
        ],
        ['08/09/2019 20:24', 'OPTION EXPIRATION', 'TWTR20190809C48.0', '4', '$0.00', '0', '$0.00', '$1,456.00'],
        ['08/09/2019 20:24', 'OPTION EXPIRATION', 'TWTR20190809C45.0', '4', '$0.00', '0', '$0.00', '$1,576.00'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_symbol_history_sq() -> None:
    data = symbol_history._gen_ascii_tbl_data(symbol='SQ')
    example = [
        ['Date', 'Event', 'Symbol', 'Quantity', 'Price', '# of Shares', 'Avg Price', 'Cumulative Profit'],
        ['06/20/2018 14:07', 'LONG CALL', 'SQ20180720C68.0', '1', '$3.70', '0', '$0.00', '$0.00'],
        ['06/22/2018 19:07', 'LONG CALL CLOSE', 'SQ20180720C68.0', '1', '$-2.03', '0', '$0.00', '$-167.00'],
        ['07/20/2018 14:15', 'SHORT PUT', 'SQ20180727P68.5', '1', '$-0.52', '0', '$0.00', '$-167.00'],
        ['07/27/2018 20:12', 'OPTION EXPIRATION', 'SQ20180727P68.5', '1', '$0.00', '0', '$0.00', '$-115.00'],
        ['08/01/2018 14:31', 'SHORT PUT', 'SQ20180803P63.0', '1', '$-1.25', '0', '$0.00', '$-115.00'],
        ['08/03/2018 20:11', 'OPTION EXPIRATION', 'SQ20180803P63.0', '1', '$0.00', '0', '$0.00', '$10.00'],
        ['09/05/2018 14:15', 'SHORT PUT', 'SQ20180907P85.0', '4', '$-0.85', '0', '$0.00', '$10.00'],
        ['09/05/2018 14:15', 'LIMIT BUY', 'SQ', '100', '$86.98', '100', '$86.98', '$10.00'],
        ['09/05/2018 15:20', 'SHORT CALL', 'SQ20180907C89.0', '1', '$-0.72', '100', '$86.98', '$10.00'],
        [
            '09/07/2018 19:47',
            'LONG CALL SPREAD', 'SQ20181026C90.0/20181026C95.0', '2', '$2.00', '100', '$86.98', '$10.00',
        ],
        ['09/07/2018 20:57', 'CALL ASSIGNMENT', 'SQ20180907C89.0', '1', '$89.00', '0', '$0.00', '$284.00'],
        ['09/07/2018 20:57', 'OPTION EXPIRATION', 'SQ20180907P85.0', '4', '$0.00', '0', '$0.00', '$624.00'],
        ['09/10/2018 13:49', 'SHORT PUT', 'SQ20180914P88.0', '1', '$-2.00', '0', '$0.00', '$624.00'],
        ['09/10/2018 13:50', 'SHORT PUT', 'SQ20180914P85.0', '1', '$-0.87', '0', '$0.00', '$624.00'],
        ['09/10/2018 13:50', 'SHORT PUT', 'SQ20180914P86.0', '1', '$-1.18', '0', '$0.00', '$624.00'],
        ['09/10/2018 13:50', 'SHORT PUT', 'SQ20180914P87.0', '1', '$-1.60', '0', '$0.00', '$624.00'],
        ['09/14/2018 20:25', 'OPTION EXPIRATION', 'SQ20180914P88.0', '1', '$0.00', '0', '$0.00', '$824.00'],
        ['09/14/2018 20:25', 'OPTION EXPIRATION', 'SQ20180914P87.0', '1', '$0.00', '0', '$0.00', '$984.00'],
        ['09/14/2018 20:25', 'OPTION EXPIRATION', 'SQ20180914P86.0', '1', '$0.00', '0', '$0.00', '$1,102.00'],
        ['09/14/2018 20:25', 'OPTION EXPIRATION', 'SQ20180914P85.0', '1', '$0.00', '0', '$0.00', '$1,189.00'],
        ['09/17/2018 13:48', 'SHORT PUT', 'SQ20180921P88.0', '1', '$-0.80', '0', '$0.00', '$1,189.00'],
        ['09/17/2018 14:05', 'SHORT PUT', 'SQ20180921P87.0', '1', '$-0.75', '0', '$0.00', '$1,189.00'],
        ['09/17/2018 14:27', 'SHORT PUT', 'SQ20180921P88.0', '1', '$-1.30', '0', '$0.00', '$1,189.00'],
        ['09/21/2018 20:30', 'PUT ASSIGNMENT', 'SQ20180921P88.0', '2', '$88.00', '200', '$86.95', '$1,189.00'],
        ['09/21/2018 20:30', 'PUT ASSIGNMENT', 'SQ20180921P87.0', '1', '$87.00', '300', '$86.72', '$1,189.00'],
        ['09/24/2018 13:47', 'LIMIT BUY', 'SQ', '100', '$84.49', '400', '$86.16', '$1,189.00'],
        ['09/24/2018 13:49', 'LIMIT BUY', 'SQ', '100', '$84.00', '500', '$85.73', '$1,189.00'],
        ['09/24/2018 13:58', 'SHORT CALL', 'SQ20180928C90.0', '1', '$-0.30', '500', '$85.73', '$1,189.00'],
        ['09/24/2018 14:01', 'SHORT CALL', 'SQ20180928C89.0', '1', '$-0.50', '500', '$85.73', '$1,189.00'],
        ['09/24/2018 14:34', 'SHORT CALL', 'SQ20180928C90.0', '3', '$-0.65', '500', '$85.73', '$1,189.00'],
        ['09/25/2018 17:59', 'LIMIT BUY', 'SQ', '100', '$94.00', '600', '$87.11', '$1,189.00'],
        ['09/25/2018 18:01', 'SHORT CALL', 'SQ20180928C100.0', '1', '$-0.54', '600', '$87.11', '$1,189.00'],
        ['09/26/2018 19:26', 'SHORT PUT', 'SQ20180928P93.0', '1', '$-0.60', '600', '$87.11', '$1,189.00'],
        ['09/27/2018 18:34', 'LONG CALL', 'SQ20180928C99.0', '1', '$1.00', '600', '$87.11', '$1,189.00'],
        [
            '09/28/2018 19:10',
            'LONG CALL SPREAD CLOSE', 'SQ20180928C99.0/20180928C100.0', '1', '$0.11', '600', '$87.11', '$1,154.00',
        ],
        ['09/28/2018 20:25', 'OPTION EXPIRATION', 'SQ20180928P93.0', '1', '$0.00', '600', '$87.11', '$1,214.00'],
        ['09/28/2018 20:25', 'CALL ASSIGNMENT', 'SQ20180928C89.0', '1', '$89.00', '500', '$87.11', '$1,453.40'],
        ['09/28/2018 20:25', 'CALL ASSIGNMENT', 'SQ20180928C90.0', '4', '$90.00', '100', '$87.11', '$2,835.98'],
        ['10/01/2018 15:21', 'SHORT PUT', 'SQ20181005P94.0', '1', '$-0.55', '100', '$87.11', '$2,835.98'],
        [
            '10/04/2018 14:12',
            'LONG CALL SPREAD CLOSE', 'SQ20181026C90.0/20181026C95.0', '2', '$-3.00', '100', '$87.11', '$3,035.98',
        ],
        ['10/04/2018 14:23', 'SHORT PUT', 'SQ20181005P93.0', '1', '$-0.60', '100', '$87.11', '$3,035.98'],
        ['10/05/2018 20:27', 'OPTION EXPIRATION', 'SQ20181005P93.0', '1', '$0.00', '100', '$87.11', '$3,095.98'],
        ['10/05/2018 20:27', 'OPTION EXPIRATION', 'SQ20181005P94.0', '1', '$0.00', '100', '$87.11', '$3,150.98'],
        ['10/08/2018 15:07', 'LIMIT BUY', 'SQ', '100', '$88.60', '200', '$87.85', '$3,150.98'],
        ['10/10/2018 15:16', 'LIMIT BUY', 'SQ', '100', '$79.00', '300', '$84.90', '$3,150.98'],
        ['11/06/2018 18:23', 'SHORT CALL', 'SQ20181109C89.5', '3', '$-0.40', '300', '$84.90', '$3,150.98'],
        [
            '11/08/2018 15:28',
            'LONG PUT SPREAD', 'SQ20190118P75.0/20190118P70.0', '2', '$2.00', '300', '$84.90', '$3,150.98',
        ],
        ['11/09/2018 18:50', 'SHORT PUT', 'SQ20181116P70.0', '1', '$-1.45', '300', '$84.90', '$3,150.98'],
        ['11/10/2018 23:36', 'OPTION EXPIRATION', 'SQ20181109C89.5', '3', '$0.00', '300', '$84.90', '$3,270.98'],
        [
            '11/13/2018 16:14',
            'LONG PUT SPREAD CLOSE', 'SQ20190118P75.0/20190118P70.0', '2', '$-2.60', '300', '$84.90', '$3,390.98',
        ],
        ['11/14/2018 15:15', 'LIMIT BUY', 'SQ', '100', '$70.00', '400', '$81.18', '$3,390.98'],
        ['11/16/2018 21:26', 'OPTION EXPIRATION', 'SQ20181116P70.0', '1', '$0.00', '400', '$81.18', '$3,535.98'],
        ['11/19/2018 15:43', 'LIMIT BUY', 'SQ', '100', '$65.00', '500', '$77.94', '$3,535.98'],
        ['11/19/2018 15:43', 'LIMIT BUY', 'SQ', '100', '$65.00', '600', '$75.78', '$3,535.98'],
        ['11/28/2018 20:38', 'LIMIT SELL', 'SQ', '100', '$70.00', '500', '$75.78', '$2,957.55'],
        ['12/04/2018 17:30', 'LIMIT BUY', 'SQ', '100', '$65.00', '600', '$73.99', '$2,957.55'],
        ['12/10/2018 14:11', 'LIMIT BUY', 'SQ', '100', '$60.00', '700', '$71.99', '$2,957.55'],
        ['12/11/2018 14:01', 'LIMIT SELL', 'SQ', '100', '$65.20', '600', '$71.99', '$2,278.67'],
        ['12/20/2018 17:52', 'LIMIT BUY', 'SQ', '100', '$55.00', '700', '$69.56', '$2,278.67'],
        ['01/07/2019 15:06', 'LIMIT SELL', 'SQ', '100', '$60.00', '600', '$69.56', '$1,322.48'],
        ['01/10/2019 14:16', 'LIMIT SELL', 'SQ', '100', '$65.00', '500', '$69.56', '$866.30'],
        ['01/18/2019 15:18', 'LIMIT SELL', 'SQ', '100', '$70.00', '400', '$69.56', '$910.12'],
        ['04/04/2019 14:48', 'SHORT CALL', 'SQ20190412C78.0', '1', '$-0.60', '400', '$69.56', '$910.12'],
        ['04/12/2019 20:23', 'OPTION EXPIRATION', 'SQ20190412C78.0', '1', '$0.00', '400', '$69.56', '$970.12'],
        ['05/01/2019 14:11', 'SHORT CALL', 'SQ20190503C80.0', '1', '$-0.64', '400', '$69.56', '$970.12'],
        ['05/01/2019 15:38', 'SHORT PUT', 'SQ20190503P68.5', '1', '$-0.45', '400', '$69.56', '$970.12'],
        ['05/02/2019 14:41', 'SHORT PUT', 'SQ20190510P65.0', '1', '$-0.57', '400', '$69.56', '$970.12'],
        ['05/03/2019 20:23', 'OPTION EXPIRATION', 'SQ20190503C80.0', '1', '$0.00', '400', '$69.56', '$1,034.12'],
        ['05/06/2019 04:26', 'PUT ASSIGNMENT', 'SQ20190503P68.5', '1', '$68.50', '500', '$69.26', '$1,034.12'],
        ['05/06/2019 13:57', 'SHORT CALL', 'SQ20190510C70.5', '1', '$-0.54', '500', '$69.26', '$1,034.12'],
        ['05/10/2019 20:23', 'OPTION EXPIRATION', 'SQ20190510C70.5', '1', '$0.00', '500', '$69.26', '$1,088.12'],
        ['05/10/2019 20:23', 'OPTION EXPIRATION', 'SQ20190510P65.0', '1', '$0.00', '500', '$69.26', '$1,145.12'],
        ['05/28/2019 15:07', 'SHORT CALL', 'SQ20190531C70.0', '1', '$-0.24', '500', '$69.26', '$1,145.12'],
        ['05/31/2019 20:23', 'OPTION EXPIRATION', 'SQ20190531C70.0', '1', '$0.00', '500', '$69.26', '$1,169.12'],
        ['06/17/2019 14:15', 'SHORT CALL', 'SQ20190621C76.0', '1', '$-0.28', '500', '$69.26', '$1,169.12'],
        ['06/20/2019 14:32', 'SHORT CALL', 'SQ20190628C77.0', '1', '$-0.48', '500', '$69.26', '$1,169.12'],
        ['06/21/2019 20:26', 'OPTION EXPIRATION', 'SQ20190621C76.0', '1', '$0.00', '500', '$69.26', '$1,197.12'],
        ['06/28/2019 20:23', 'OPTION EXPIRATION', 'SQ20190628C77.0', '1', '$0.00', '500', '$69.26', '$1,245.12'],
        ['07/09/2019 14:05', 'SHORT CALL', 'SQ20190712C80.0', '5', '$-0.26', '500', '$69.26', '$1,245.12'],
        ['07/12/2019 20:22', 'CALL ASSIGNMENT', 'SQ20190712C80.0', '5', '$80.00', '0', '$0.00', '$6,745.38'],
        ['07/15/2019 14:24', 'SHORT PUT', 'SQ20190719P80.0', '5', '$-0.54', '0', '$0.00', '$6,745.38'],
        ['07/19/2019 20:40', 'PUT ASSIGNMENT', 'SQ20190719P80.0', '5', '$80.00', '500', '$79.46', '$6,745.38'],
        ['07/22/2019 13:33', 'SHORT CALL', 'SQ20190726C80.0', '5', '$-0.92', '500', '$79.46', '$6,745.38'],
        ['07/26/2019 20:22', 'CALL ASSIGNMENT', 'SQ20190726C80.0', '5', '$80.00', '0', '$0.00', '$7,475.38'],
        ['07/29/2019 15:58', 'SHORT PUT', 'SQ20190802P80.0', '5', '$-2.85', '0', '$0.00', '$7,475.38'],
        ['08/02/2019 20:23', 'PUT ASSIGNMENT', 'SQ20190802P80.0', '5', '$80.00', '500', '$77.15', '$7,475.38'],
        ['08/05/2019 15:25', 'SHORT PUT', 'SQ20190809P62.0', '10', '$-0.80', '500', '$77.15', '$7,475.38'],
        ['08/08/2019 16:22', 'BUY TO CLOSE', 'SQ20190809P62.0', '1', '$0.03', '500', '$77.15', '$7,552.38'],
        ['08/09/2019 20:24', 'OPTION EXPIRATION', 'SQ20190809P62.0', '9', '$0.00', '500', '$77.15', '$8,272.38'],
        ['08/14/2019 16:26', 'SHORT PUT', 'SQ20190816P60.0', '10', '$-0.73', '500', '$77.15', '$8,272.38'],
        ['08/16/2019 20:38', 'OPTION EXPIRATION', 'SQ20190816P60.0', '10', '$0.00', '500', '$77.15', '$9,002.38'],
        ['08/23/2019 17:34', 'SHORT PUT', 'SQ20190830P60.0', '10', '$-1.03', '500', '$77.15', '$9,002.38'],
        ['08/26/2019 19:11', 'SHORT CALL', 'SQ20190830C63.0', '5', '$-1.02', '500', '$77.15', '$9,002.38'],
        ['08/30/2019 20:22', 'OPTION EXPIRATION', 'SQ20190830C63.0', '5', '$0.00', '500', '$77.15', '$9,512.38'],
        ['08/30/2019 20:22', 'OPTION EXPIRATION', 'SQ20190830P60.0', '10', '$0.00', '500', '$77.15', '$10,542.38'],
        ['09/03/2019 15:03', 'SHORT CALL', 'SQ20190906C63.0', '5', '$-1.06', '500', '$77.15', '$10,542.38'],
        ['09/03/2019 15:05', 'SHORT PUT', 'SQ20190906P62.5', '10', '$-0.98', '500', '$77.15', '$10,542.38'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_symbol_history_tlry() -> None:
    data = symbol_history._gen_ascii_tbl_data(symbol='TLRY')
    example = [
        ['Date', 'Event', 'Symbol', 'Quantity', 'Price', '# of Shares', 'Avg Price', 'Cumulative Profit'],
        ['08/29/2018 17:34', 'SHORT PUT', 'TLRY20180921P45.0', '1', '$-2.00', '0', '$0.00', '$0.00'],
        ['09/05/2018 16:48', 'SHORT PUT', 'TLRY20180907P71.5', '1', '$-1.65', '0', '$0.00', '$0.00'],
        ['09/07/2018 20:57', 'OPTION EXPIRATION', 'TLRY20180907P71.5', '1', '$0.00', '0', '$0.00', '$165.00'],
        ['09/17/2018 14:49', 'BUY TO CLOSE', 'TLRY20180921P45.0', '1', '$0.05', '0', '$0.00', '$360.00'],
        ['09/24/2018 14:49', 'SHORT PUT', 'TLRY20180928P70.0', '1', '$-1.50', '0', '$0.00', '$360.00'],
        ['09/28/2018 20:25', 'OPTION EXPIRATION', 'TLRY20180928P70.0', '1', '$0.00', '0', '$0.00', '$510.00'],
        ['10/01/2018 17:57', 'SHORT PUT', 'TLRY20181005P120.0', '1', '$-1.70', '0', '$0.00', '$510.00'],
        ['10/05/2018 20:27', 'OPTION EXPIRATION', 'TLRY20181005P120.0', '1', '$0.00', '0', '$0.00', '$680.00'],
        ['02/22/2019 19:08', 'LIMIT BUY', 'TLRY', '100', '$78.60', '100', '$78.60', '$680.00'],
        ['03/08/2019 14:46', 'LIMIT BUY', 'TLRY', '100', '$67.00', '200', '$72.80', '$680.00'],
        ['04/05/2019 15:13', 'LIMIT BUY', 'TLRY', '100', '$60.00', '300', '$68.53', '$680.00'],
        ['04/08/2019 15:39', 'SHORT PUT', 'TLRY20190412P55.0', '1', '$-1.20', '300', '$68.53', '$680.00'],
        ['04/12/2019 20:23', 'PUT ASSIGNMENT', 'TLRY20190412P55.0', '1', '$55.00', '400', '$64.85', '$680.00'],
        ['04/15/2019 13:40', 'SHORT CALL', 'TLRY20190418C55.0', '1', '$-0.44', '400', '$64.85', '$680.00'],
        ['04/15/2019 14:11', 'SHORT PUT', 'TLRY20190418P50.0', '1', '$-0.71', '400', '$64.85', '$680.00'],
        ['04/18/2019 20:26', 'PUT ASSIGNMENT', 'TLRY20190418P50.0', '1', '$50.00', '500', '$61.74', '$680.00'],
        ['04/18/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190418C55.0', '1', '$0.00', '500', '$61.74', '$724.00'],
        ['04/29/2019 14:36', 'SHORT CALL', 'TLRY20190503C55.0', '1', '$-0.66', '500', '$61.74', '$724.00'],
        ['05/02/2019 15:19', 'SHORT PUT', 'TLRY20190510P45.0', '1', '$-0.53', '500', '$61.74', '$724.00'],
        ['05/03/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190503C55.0', '1', '$0.00', '500', '$61.74', '$790.00'],
        ['05/10/2019 18:22', 'SHORT CALL', 'TLRY20190517C55.0', '1', '$-1.18', '500', '$61.74', '$790.00'],
        ['05/10/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190510P45.0', '1', '$0.00', '500', '$61.74', '$843.00'],
        ['05/14/2019 15:39', 'SHORT CALL', 'TLRY20190517C60.0', '1', '$-0.19', '500', '$61.74', '$843.00'],
        ['05/14/2019 15:42', 'SHORT PUT', 'TLRY20190517P43.5', '2', '$-0.76', '500', '$61.74', '$843.00'],
        ['05/17/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190517P43.5', '2', '$0.00', '500', '$61.74', '$995.00'],
        ['05/17/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190517C60.0', '1', '$0.00', '500', '$61.74', '$1,014.00'],
        ['05/17/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190517C55.0', '1', '$0.00', '500', '$61.74', '$1,132.00'],
        ['06/10/2019 14:45', 'SHORT PUT', 'TLRY20190614P38.5', '2', '$-0.66', '500', '$61.74', '$1,132.00'],
        ['06/10/2019 16:10', 'SHORT CALL', 'TLRY20190614C57.0', '1', '$-1.07', '500', '$61.74', '$1,132.00'],
        ['06/11/2019 15:43', 'SHORT CALL', 'TLRY20190614C44.5', '1', '$-0.33', '500', '$61.74', '$1,132.00'],
        ['06/14/2019 20:22', 'OPTION EXPIRATION', 'TLRY20190614C44.5', '1', '$0.00', '500', '$61.74', '$1,165.00'],
        ['06/14/2019 20:22', 'OPTION EXPIRATION', 'TLRY20190614C57.0', '1', '$0.00', '500', '$61.74', '$1,272.00'],
        ['06/14/2019 20:22', 'OPTION EXPIRATION', 'TLRY20190614P38.5', '2', '$0.00', '500', '$61.74', '$1,404.00'],
        ['06/17/2019 13:53', 'SHORT CALL', 'TLRY20190621C44.5', '1', '$-0.35', '500', '$61.74', '$1,404.00'],
        ['06/17/2019 14:31', 'SHORT CALL', 'TLRY20190621C45.5', '1', '$-0.50', '500', '$61.74', '$1,404.00'],
        ['06/18/2019 15:53', 'SHORT PUT', 'TLRY20190621P37.5', '2', '$-0.25', '500', '$61.74', '$1,404.00'],
        ['06/19/2019 15:04', 'SHORT CALL', 'TLRY20190621C46.5', '1', '$-0.51', '500', '$61.74', '$1,404.00'],
        ['06/19/2019 19:42', 'SHORT CALL', 'TLRY20190621C48.5', '1', '$-0.55', '500', '$61.74', '$1,404.00'],
        ['06/20/2019 15:12', 'SHORT CALL', 'TLRY20190621C50.5', '1', '$-0.43', '500', '$61.74', '$1,404.00'],
        ['06/20/2019 15:14', 'SHORT PUT', 'TLRY20190621P44.5', '1', '$-0.47', '500', '$61.74', '$1,404.00'],
        ['06/21/2019 13:44', 'SHORT PUT', 'TLRY20190628P42.0', '1', '$-0.69', '500', '$61.74', '$1,404.00'],
        ['06/21/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190621P44.5', '1', '$0.00', '500', '$61.74', '$1,451.00'],
        ['06/21/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190621P37.5', '2', '$0.00', '500', '$61.74', '$1,501.00'],
        ['06/21/2019 20:26', 'OPTION EXPIRATION', 'TLRY20190621C50.5', '1', '$0.00', '500', '$61.74', '$1,544.00'],
        ['06/21/2019 20:26', 'CALL ASSIGNMENT', 'TLRY20190621C48.5', '1', '$48.50', '400', '$61.74', '$275.20'],
        ['06/21/2019 20:26', 'CALL ASSIGNMENT', 'TLRY20190621C46.5', '1', '$46.50', '300', '$61.74', '$-1,197.60'],
        ['06/21/2019 20:26', 'CALL ASSIGNMENT', 'TLRY20190621C45.5', '1', '$45.50', '200', '$61.74', '$-2,771.40'],
        ['06/21/2019 20:26', 'CALL ASSIGNMENT', 'TLRY20190621C44.5', '1', '$44.50', '100', '$61.74', '$-4,460.20'],
        ['06/24/2019 13:38', 'SHORT PUT', 'TLRY20190628P45.0', '4', '$-0.99', '100', '$61.74', '$-4,460.20'],
        ['06/24/2019 14:19', 'SHORT CALL', 'TLRY20190628C56.0', '1', '$-0.69', '100', '$61.74', '$-4,460.20'],
        ['06/28/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190628P45.0', '4', '$0.00', '100', '$61.74', '$-4,064.20'],
        ['06/28/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190628C56.0', '1', '$0.00', '100', '$61.74', '$-3,995.20'],
        ['06/28/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190628P42.0', '1', '$0.00', '100', '$61.74', '$-3,926.20'],
        ['07/01/2019 15:07', 'SHORT PUT', 'TLRY20190705P45.0', '4', '$-0.68', '100', '$61.74', '$-3,926.20'],
        ['07/01/2019 16:18', 'SHORT CALL', 'TLRY20190705C50.0', '1', '$-0.46', '100', '$61.74', '$-3,926.20'],
        ['07/05/2019 20:24', 'OPTION EXPIRATION', 'TLRY20190705C50.0', '1', '$0.00', '100', '$61.74', '$-3,880.20'],
        ['07/05/2019 20:24', 'OPTION EXPIRATION', 'TLRY20190705P45.0', '4', '$0.00', '100', '$61.74', '$-3,608.20'],
        ['07/08/2019 14:12', 'SHORT CALL', 'TLRY20190712C52.0', '1', '$-0.38', '100', '$61.74', '$-3,608.20'],
        ['07/08/2019 14:14', 'SHORT PUT', 'TLRY20190712P45.0', '4', '$-0.41', '100', '$61.74', '$-3,608.20'],
        ['07/12/2019 20:22', 'PUT ASSIGNMENT', 'TLRY20190712P45.0', '4', '$45.00', '500', '$48.02', '$-3,608.20'],
        ['07/12/2019 20:22', 'OPTION EXPIRATION', 'TLRY20190712C52.0', '1', '$0.00', '500', '$48.02', '$-3,570.20'],
        ['07/15/2019 14:06', 'SHORT PUT', 'TLRY20190719P41.0', '3', '$-0.34', '500', '$48.02', '$-3,570.20'],
        ['07/15/2019 14:14', 'SHORT CALL', 'TLRY20190719C46.0', '5', '$-0.42', '500', '$48.02', '$-3,570.20'],
        ['07/19/2019 20:40', 'OPTION EXPIRATION', 'TLRY20190719C46.0', '5', '$0.00', '500', '$48.02', '$-3,360.20'],
        ['07/19/2019 20:40', 'OPTION EXPIRATION', 'TLRY20190719P41.0', '3', '$0.00', '500', '$48.02', '$-3,258.20'],
        ['07/22/2019 20:40', 'SHORT PUT', 'TLRY20190726P40.0', '3', '$-0.32', '500', '$48.02', '$-3,258.20'],
        ['07/26/2019 20:22', 'OPTION EXPIRATION', 'TLRY20190726P40.0', '3', '$0.00', '500', '$48.02', '$-3,162.20'],
        ['07/29/2019 16:57', 'SHORT PUT', 'TLRY20190802P39.0', '10', '$-0.69', '500', '$48.02', '$-3,162.20'],
        ['07/30/2019 15:48', 'SHORT CALL', 'TLRY20190802C43.5', '5', '$-0.19', '500', '$48.02', '$-3,162.20'],
        ['08/02/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190802C43.5', '5', '$0.00', '500', '$48.02', '$-3,067.20'],
        ['08/02/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190802P39.0', '10', '$0.00', '500', '$48.02', '$-2,377.20'],
        ['08/05/2019 15:24', 'SHORT CALL', 'TLRY20190809C45.5', '5', '$-0.39', '500', '$48.02', '$-2,377.20'],
        ['08/09/2019 20:24', 'OPTION EXPIRATION', 'TLRY20190809C45.5', '5', '$0.00', '500', '$48.02', '$-2,182.20'],
        ['08/12/2019 16:26', 'SHORT PUT', 'TLRY20190816P36.0', '10', '$-0.40', '500', '$48.02', '$-2,182.20'],
        ['08/12/2019 19:08', 'SHORT CALL', 'TLRY20190816C46.5', '5', '$-0.90', '500', '$48.02', '$-2,182.20'],
        [
            '08/13/2019 18:02',
            'ROLLING CALL', 'TLRY20190816C46.5/20190823C47.5', '5', '$-0.09', '500', '$48.02', '$-2,182.20',
        ],
        ['08/16/2019 20:38', 'PUT ASSIGNMENT', 'TLRY20190816P36.0', '10', '$36.00', '1,500', '$39.74', '$-2,182.20'],
        ['08/19/2019 13:42', 'SHORT PUT', 'TLRY20190823P30.0', '15', '$-1.10', '1,500', '$39.74', '$-2,182.20'],
        ['08/19/2019 13:54', 'BUY TO CLOSE', 'TLRY20190823P30.0', '15', '$1.76', '1,500', '$39.74', '$-3,172.20'],
        ['08/19/2019 14:10', 'SHORT PUT', 'TLRY20190823P30.0', '15', '$-2.00', '1,500', '$39.74', '$-3,172.20'],
        ['08/19/2019 14:14', 'SHORT CALL', 'TLRY20190823C30.0', '10', '$-1.04', '1,500', '$39.74', '$-3,172.20'],
        [
            '08/19/2019 15:03',
            'ROLLING CALL', 'TLRY20190823C47.5/20190823C30.0', '5', '$-1.38', '1,500', '$39.74', '$-3,172.20',
        ],
        ['08/19/2019 15:41', 'BUY TO CLOSE', 'TLRY20190823P30.0', '15', '$1.18', '1,500', '$39.74', '$-1,942.20'],
        ['08/20/2019 15:37', 'SHORT PUT', 'TLRY20190823P29.5', '15', '$-1.06', '1,500', '$39.74', '$-1,942.20'],
        [
            '08/23/2019 15:51',
            'ROLLING PUT', 'TLRY20190823P29.5/20190830P28.5', '15', '$-0.56', '1,500', '$39.74', '$-1,942.20',
        ],
        ['08/23/2019 20:21', 'OPTION EXPIRATION', 'TLRY20190823C30.0', '15', '$0.00', '1,500', '$39.74', '$282.80'],
        [
            '08/27/2019 17:21',
            'ROLLING PUT', 'TLRY20190830P28.5/20190906P28.0', '15', '$-0.18', '1,500', '$39.74', '$282.80',
        ],
        ['08/27/2019 17:23', 'SHORT PUT', 'TLRY20190830P26.5', '5', '$-1.04', '1,500', '$39.74', '$282.80'],
        ['08/28/2019 14:25', 'SHORT CALL', 'TLRY20190830C27.5', '15', '$-0.46', '1,500', '$39.74', '$282.80'],
        ['08/30/2019 18:45', 'BUY TO CLOSE', 'TLRY20190830P26.5', '5', '$0.78', '1,500', '$39.74', '$412.80'],
        ['08/30/2019 20:22', 'OPTION EXPIRATION', 'TLRY20190830C27.5', '15', '$0.00', '1,500', '$39.74', '$1,102.80'],
        ['09/03/2019 14:28', 'SHORT CALL', 'TLRY20190906C26.5', '15', '$-0.69', '1,500', '$39.74', '$1,102.80'],
        [
            '09/03/2019 14:37',
            'ROLLING PUT', 'TLRY20190906P28.0/20190913P27.5', '15', '$-0.30', '1,500', '$39.74', '$1,102.80',
        ],
        [
            '09/03/2019 18:19',
            'ROLLING CALL', 'TLRY20190906C26.5/20190913C27.0', '15', '$-0.08', '1,500', '$39.74', '$1,102.80',
        ],
        ['09/13/2019 20:23', 'CALL ASSIGNMENT', 'TLRY20190913C27.0', '15', '$27.00', '0', '$0.00', '$-16,852.00'],
        ['09/13/2019 20:23', 'OPTION EXPIRATION', 'TLRY20190913P27.5', '15', '$0.00', '0', '$0.00', '$-13,702.00'],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_symbol_history_shop() -> None:
    data = symbol_history._gen_ascii_tbl_data(symbol='SHOP')
    example = [
        ['Date', 'Event', 'Symbol', 'Quantity', 'Price', '# of Shares', 'Avg Price', 'Cumulative Profit'],
        ['07/31/2019 19:39', 'SHORT PUT', 'SHOP20190802P285.0', '1', '$-2.10', '0', '$0.00', '$0.00'],
        ['08/01/2019 17:56', 'BUY TO CLOSE', 'SHOP20190802P285.0', '1', '$0.05', '0', '$0.00', '$205.00'],
        [
            '10/08/2019 18:02',
            'SHORT PUT SPREAD', 'SHOP20191011P302.5/20191011P260.0',
            '1', '$-2.30', '0', '$0.00', '$205.00',
        ],
        [
            '10/09/2019 14:52',
            'SHORT CALL SPREAD',
            'SHOP20191011C315.0/20191011C342.5',
            '1', '$-5.75', '0', '$0.00', '$205.00',
        ],
        [
            '10/10/2019 16:28',
            'ROLLING SHORT CALL SPREAD',
            '-SHOP20191011C342.5-/-SHOP20191018C320.0/SHOP20191011C315.0-/SHOP20191018C400.0',
            '1', '$-0.93', '0', '$0.00', '$205.00',
        ],
        ['10/11/2019 20:27', 'OPTION EXPIRATION', 'SHOP20191011P260.0', '1', '$0.00', '0', '$0.00', '$185.00'],
        ['10/11/2019 20:27', 'OPTION EXPIRATION', 'SHOP20191011P302.5', '1', '$0.00', '0', '$0.00', '$435.00'],
        [
            '10/14/2019 15:37',
            'SHORT CALL SPREAD',
            'SHOP20191018C355.0/20191018C430.0',
            '1', '$-2.53', '0', '$0.00', '$435.00',
        ],
        [
            '10/14/2019 19:00',
            'SHORT CALL SPREAD',
            'SHOP20191018C360.0/20191018C410.0',
            '1', '$-2.40', '0', '$0.00', '$435.00',
        ],
        [
            '10/16/2019 15:43',
            'SHORT PUT SPREAD',
            'SHOP20191018P320.0/20191018P290.0',
            '3', '$-1.08', '0', '$0.00', '$435.00',
        ],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_symbol_history_nvda() -> None:
    data = symbol_history._gen_ascii_tbl_data(symbol='NVDA')
    example = [
        ['Date', 'Event', 'Symbol', 'Quantity', 'Price', '# of Shares', 'Avg Price', 'Cumulative Profit'],
        ['07/19/2018 14:50', 'LONG CALL', 'NVDA20180921C245.0', '1', '$18.45', '0', '$0.00', '$0.00'],
        ['07/19/2018 14:52', 'SHORT CALL', 'NVDA20180921C255.0', '1', '$-13.20', '0', '$0.00', '$0.00'],
        ['08/13/2018 13:37', 'BUY TO CLOSE', 'NVDA20180921C255.0', '1', '$14.85', '0', '$0.00', '$-165.00'],
        ['08/13/2018 13:38', 'LONG CALL CLOSE', 'NVDA20180921C245.0', '1', '$-21.50', '0', '$0.00', '$140.00'],
        ['08/16/2018 15:02', 'SHORT PUT', 'NVDA20180817P230.0', '1', '$-0.85', '0', '$0.00', '$140.00'],
        [
            '08/17/2018 14:24',
            'LONG CALL SPREAD', 'NVDA20181019C245.0/20181019C255.0', '1', '$4.65', '0', '$0.00', '$140.00',
        ],
        ['08/17/2018 20:15', 'OPTION EXPIRATION', 'NVDA20180817P230.0', '1', '$0.00', '0', '$0.00', '$225.00'],
        [
            '08/24/2018 16:10',
            'LONG CALL SPREAD CLOSE', 'NVDA20181019C245.0/20181019C255.0', '1', '$-8.00', '0', '$0.00', '$560.00',
        ],
        [
            '09/25/2018 19:56',
            'LONG CALL SPREAD', 'NVDA20181116C270.0/20181116C275.0', '2', '$2.40', '0', '$0.00', '$560.00',
        ],
        [
            '10/01/2018 15:40',
            'LONG CALL SPREAD CLOSE', 'NVDA20181116C270.0/20181116C275.0', '2', '$-3.50', '0', '$0.00', '$780.00',
        ],
        ['11/14/2018 14:52', 'SHORT PUT', 'NVDA20181116P180.0', '2', '$-2.65', '0', '$0.00', '$780.00'],
        ['11/16/2018 21:26', 'PUT ASSIGNMENT', 'NVDA20181116P180.0', '2', '$180.00', '200', '$177.35', '$780.00'],
        ['11/29/2018 15:20', 'SHORT CALL', 'NVDA20181207C180.0', '2', '$-0.33', '200', '$177.35', '$780.00'],
        ['12/07/2018 21:24', 'OPTION EXPIRATION', 'NVDA20181207C180.0', '2', '$0.00', '200', '$177.35', '$846.00'],
        ['04/15/2019 14:08', 'SHORT CALL', 'NVDA20190418C192.5', '2', '$-0.90', '200', '$177.35', '$846.00'],
        ['04/18/2019 20:26', 'OPTION EXPIRATION', 'NVDA20190418C192.5', '2', '$0.00', '200', '$177.35', '$1,026.00'],
        ['04/26/2019 15:37', 'SHORT PUT', 'NVDA20190503P170.0', '1', '$-1.45', '200', '$177.35', '$1,026.00'],
        ['05/02/2019 14:56', 'SHORT CALL', 'NVDA20190510C195.0', '1', '$-0.56', '200', '$177.35', '$1,026.00'],
        ['05/03/2019 20:23', 'OPTION EXPIRATION', 'NVDA20190503P170.0', '1', '$0.00', '200', '$177.35', '$1,171.00'],
        ['05/06/2019 14:06', 'SHORT PUT', 'NVDA20190510P170.0', '1', '$-1.34', '200', '$177.35', '$1,171.00'],
        ['05/09/2019 15:41', 'SHORT PUT', 'NVDA20190517P150.0', '1', '$-2.33', '200', '$177.35', '$1,171.00'],
        ['05/10/2019 20:23', 'PUT ASSIGNMENT', 'NVDA20190510P170.0', '1', '$170.00', '300', '$174.45', '$1,171.00'],
        ['05/10/2019 20:23', 'OPTION EXPIRATION', 'NVDA20190510C195.0', '1', '$0.00', '300', '$174.45', '$1,227.00'],
        ['05/13/2019 14:21', 'SHORT PUT', 'NVDA20190517P140.0', '1', '$-1.09', '300', '$174.45', '$1,227.00'],
        ['05/13/2019 14:21', 'SHORT CALL', 'NVDA20190517C170.0', '1', '$-4.00', '300', '$174.45', '$1,227.00'],
        ['05/13/2019 14:33', 'BUY TO CLOSE', 'NVDA20190517C170.0', '1', '$3.70', '300', '$174.45', '$1,257.00'],
        ['05/14/2019 16:16', 'SHORT CALL', 'NVDA20190517C170.0', '1', '$-3.05', '300', '$174.45', '$1,257.00'],
        ['05/17/2019 20:26', 'OPTION EXPIRATION', 'NVDA20190517C170.0', '1', '$0.00', '300', '$174.45', '$1,562.00'],
        ['05/17/2019 20:26', 'OPTION EXPIRATION', 'NVDA20190517P140.0', '1', '$0.00', '300', '$174.45', '$1,671.00'],
        ['05/17/2019 20:26', 'OPTION EXPIRATION', 'NVDA20190517P150.0', '1', '$0.00', '300', '$174.45', '$1,904.00'],
        ['06/04/2019 14:57', 'SHORT CALL', 'NVDA20190607C145.0', '1', '$-0.65', '300', '$174.45', '$1,904.00'],
        ['06/06/2019 15:35', 'SHORT CALL', 'NVDA20190607C146.0', '1', '$-0.41', '300', '$174.45', '$1,904.00'],
        ['06/07/2019 20:23', 'OPTION EXPIRATION', 'NVDA20190607C146.0', '1', '$0.00', '300', '$174.45', '$1,945.00'],
        ['06/07/2019 20:23', 'CALL ASSIGNMENT', 'NVDA20190607C145.0', '1', '$145.00', '200', '$174.45', '$-935.33'],
        ['06/10/2019 13:41', 'SHORT PUT', 'NVDA20190614P145.0', '1', '$-1.37', '200', '$174.45', '$-935.33'],
        ['06/14/2019 20:22', 'PUT ASSIGNMENT', 'NVDA20190614P145.0', '1', '$145.00', '300', '$164.18', '$-935.33'],
        ['06/17/2019 16:24', 'SHORT CALL', 'NVDA20190621C155.0', '1', '$-0.32', '300', '$164.18', '$-935.33'],
        ['06/18/2019 13:43', 'SHORT CALL', 'NVDA20190621C157.5', '1', '$-0.58', '300', '$164.18', '$-935.33'],
        ['06/21/2019 20:26', 'OPTION EXPIRATION', 'NVDA20190621C157.5', '1', '$0.00', '300', '$164.18', '$-877.33'],
        ['06/21/2019 20:26', 'OPTION EXPIRATION', 'NVDA20190621C155.0', '1', '$0.00', '300', '$164.18', '$-845.33'],
        ['06/24/2019 14:18', 'SHORT CALL', 'NVDA20190628C160.0', '1', '$-0.56', '300', '$164.18', '$-845.33'],
        ['06/25/2019 16:42', 'SHORT CALL', 'NVDA20190712C165.0', '1', '$-1.45', '300', '$164.18', '$-845.33'],
        ['06/25/2019 16:48', 'SHORT CALL', 'NVDA20190705C165.0', '1', '$-0.87', '300', '$164.18', '$-845.33'],
        ['06/28/2019 14:00', 'SHORT PUT', 'NVDA20190705P157.5', '1', '$-1.83', '300', '$164.18', '$-845.33'],
        ['06/28/2019 20:23', 'CALL ASSIGNMENT', 'NVDA20190628C160.0', '1', '$160.00', '200', '$164.18', '$-1,207.22'],
        ['07/02/2019 19:31', 'SHORT PUT', 'NVDA20190712P157.5', '1', '$-1.63', '200', '$164.18', '$-1,207.22'],
        ['07/05/2019 20:24', 'OPTION EXPIRATION', 'NVDA20190705P157.5', '1', '$0.00', '200', '$164.18', '$-1,024.22'],
        ['07/05/2019 20:24', 'OPTION EXPIRATION', 'NVDA20190705C165.0', '1', '$0.00', '200', '$164.18', '$-937.22'],
        ['07/12/2019 20:22', 'OPTION EXPIRATION', 'NVDA20190712P157.5', '1', '$0.00', '200', '$164.18', '$-774.22'],
        ['07/12/2019 20:22', 'CALL ASSIGNMENT', 'NVDA20190712C165.0', '1', '$165.00', '100', '$164.18', '$-547.11'],
        ['07/15/2019 14:22', 'SHORT PUT', 'NVDA20190719P165.0', '1', '$-1.73', '100', '$164.18', '$-547.11'],
        ['07/15/2019 15:11', 'SHORT CALL', 'NVDA20190719C172.5', '1', '$-0.67', '100', '$164.18', '$-547.11'],
        ['07/19/2019 20:40', 'OPTION EXPIRATION', 'NVDA20190719C172.5', '1', '$0.00', '100', '$164.18', '$-480.11'],
        ['07/19/2019 20:40', 'OPTION EXPIRATION', 'NVDA20190719P165.0', '1', '$0.00', '100', '$164.18', '$-307.11'],
        ['07/22/2019 15:34', 'SHORT CALL', 'NVDA20190726C175.0', '1', '$-1.09', '100', '$164.18', '$-307.11'],
        ['07/29/2019 04:26', 'OPTION EXPIRATION', 'NVDA20190726C175.0', '1', '$0.00', '100', '$164.18', '$-198.11'],
        ['07/29/2019 14:30', 'SHORT CALL', 'NVDA20190802C180.0', '1', '$-0.74', '100', '$164.18', '$-198.11'],
        ['08/02/2019 20:23', 'OPTION EXPIRATION', 'NVDA20190802C180.0', '1', '$0.00', '100', '$164.18', '$-124.11'],
        ['08/12/2019 13:49', 'SHORT CALL', 'NVDA20190816C165.0', '1', '$-1.92', '100', '$164.18', '$-124.11'],
        ['08/12/2019 14:45', 'SHORT PUT', 'NVDA20190816P140.0', '2', '$-1.75', '100', '$164.18', '$-124.11'],
        ['08/16/2019 20:38', 'OPTION EXPIRATION', 'NVDA20190816P140.0', '2', '$0.00', '100', '$164.18', '$225.89'],
        ['08/16/2019 20:38', 'OPTION EXPIRATION', 'NVDA20190816C165.0', '1', '$0.00', '100', '$164.18', '$417.89'],
        ['08/19/2019 16:16', 'SHORT CALL', 'NVDA20190823C170.0', '1', '$-2.64', '100', '$164.18', '$417.89'],
        ['08/23/2019 20:21', 'OPTION EXPIRATION', 'NVDA20190823C170.0', '1', '$0.00', '100', '$164.18', '$681.89'],
        ['08/26/2019 15:46', 'SHORT CALL', 'NVDA20190830C167.5', '1', '$-2.62', '100', '$164.18', '$681.89'],
        ['08/26/2019 19:15', 'SHORT PUT', 'NVDA20190830P162.5', '2', '$-2.34', '100', '$164.18', '$681.89'],
        ['08/30/2019 20:22', 'OPTION EXPIRATION', 'NVDA20190830P162.5', '2', '$0.00', '100', '$164.18', '$1,149.89'],
        ['09/02/2019 04:26', 'OPTION EXPIRATION', 'NVDA20190830C167.5', '1', '$0.00', '100', '$164.18', '$1,411.89'],
        ['09/04/2019 14:24', 'SHORT CALL', 'NVDA20190906C167.5', '1', '$-2.46', '100', '$164.18', '$1,411.89'],
        [
            '09/05/2019 13:55',
            'ROLLING CALL', 'NVDA20190906C167.5/20190913C170.0', '1', '$1.18', '100', '$164.18', '$1,411.89',
        ],
        [
            '09/12/2019 16:03',
            'ROLLING CALL', 'NVDA20190913C170.0/20190920C172.5', '1', '$2.00', '100', '$164.18', '$1,411.89',
        ],
    ]
    for i in range(len(example)):
        assert example[i] == data[i]


def test_symbol_history() -> None:
    symbol_history.show_current_positions()
